@@ -9,7 +9,7 @@ from netbox.forms import (
     NetBoxModelForm,
 )
 from netbox_storage.models import Drive, Filesystem, Partition, PhysicalVolume, VolumeGroup, LogicalVolume, \
-    StorageConfigurationLinuxVolume, MountedVolume
+    StorageConfigurationLinuxVolume, MountedVolume, LinuxDevice
 from utilities.forms import (
     DynamicModelChoiceField, APISelect,
 )
@@ -199,11 +199,14 @@ class LinuxVolumeSimpleForm(NetBoxModelForm):
     def save(self, *args, **kwargs):
 
         drive = Drive.objects.create(cluster=self.cleaned_data['cluster'], size=self.cleaned_data['size'])
-        partition = Partition.objects.create(drive=drive, device=drive.device_name(), size=self.cleaned_data['size'],
-                                             type='Linux', description='Partition 1 on SSD Cluster')
-        linux_volume = MountedVolume.objects.create(partition=partition, size=self.cleaned_data['size'],
+        linux_device = LinuxDevice.objects.create(drive=drive, device=drive.device_name(), size=self.cleaned_data['size'], type='disk')
+
+        # partition = Partition.objects.create(drive=drive, device=drive.device_name(), size=self.cleaned_data['size'],
+        #                                      type='Linux', description='Partition 1 on SSD Cluster')
+
+        linux_volume = MountedVolume.objects.create(device=linux_device, size=self.cleaned_data['size'],
                                                     path=self.cleaned_data['path'], fs=self.cleaned_data['fs'],
-                                                    description='Linux volume', )
+                                                    description='Linux volume')
         self.instance.linux_volume = linux_volume
         storage_configuration = super().save(*args, **kwargs)
 
@@ -213,7 +216,7 @@ class LinuxVolumeSimpleForm(NetBoxModelForm):
 
         print("Instances")
         print(drive)
-        print(partition)
+        print(linux_device)
         print(linux_volume)
         print(storage_configuration)
 
