@@ -68,6 +68,39 @@ class Drive(NetBoxModel):
         return self.size - current_partition_allocated_space
 
 
+class LinuxDevice(NetBoxModel):
+    drive = models.ForeignKey(
+        Drive,
+        on_delete=models.CASCADE,
+        related_name='drive_device',
+    )
+    device = models.CharField(
+        max_length=255,
+    )
+    size = models.FloatField(
+        verbose_name="Size (GB)"
+    )
+    type = models.CharField(
+        max_length=255,
+    )
+    description = models.CharField(
+        max_length=255,
+        blank=True,
+    )
+
+    clone_fields = ["drive", "device", "size", "type", "description"]
+
+    prerequisite_models = (
+        'netbox_storage.Drive',
+    )
+
+    class Meta:
+        ordering = ["size"]
+
+    def __str__(self):
+        return f'{self.device}'
+
+
 class Partition(NetBoxModel):
     drive = models.ForeignKey(
         Drive,
@@ -286,10 +319,10 @@ class LogicalVolume(NetBoxModel):
 
 
 class MountedVolume(NetBoxModel):
-    partition = models.ForeignKey(
-        Partition,
+    device = models.ForeignKey(
+        LinuxDevice,
         on_delete=models.CASCADE,
-        related_name='partition_mounted_volume',
+        related_name='device_mounted_volume',
     )
     size = models.FloatField(
         verbose_name="Size (GB)"
@@ -312,7 +345,7 @@ class MountedVolume(NetBoxModel):
     )
 
     clone_fields = [
-        "partition",
+        "device",
         "size",
         "path",
         "fs",
@@ -323,7 +356,7 @@ class MountedVolume(NetBoxModel):
         return reverse("plugins:netbox_storage:mountedvolume", kwargs={"pk": self.pk})
 
     def __str__(self):
-        return f"{self.partition.device}"
+        return f"{self.device.device}"
 
     class Meta:
         ordering = ("size", "path", "description")
@@ -374,7 +407,7 @@ class TemplateConfigurationLinuxVolume(NetBoxModel):
     ]
 
     class Meta:
-        ordering = ["virtual_machine", "platform"]
+        ordering = ["linux_volume", "platform"]
 
     # def get_absolute_url(self):
     #     return reverse("plugins:netbox_storage:storageconfiguration", kwargs={"pk": self.pk})
