@@ -1,7 +1,7 @@
 from django.urls import path
 
 from netbox.views.generic import ObjectChangeLogView
-from netbox_storage.models import Drive, Filesystem, Partition, LinuxVolume
+from netbox_storage.models import Drive, Filesystem, Partition, MountedVolume
 from netbox_storage.views import (
     # Drive View
     DriveListView,
@@ -32,13 +32,13 @@ from netbox_storage.views import (
     # VolumeGroup
     # LogicalVolume
     # LinuxVolume
-    LinuxVolumeListView,
-    LinuxVolumeEditView,
-    LinuxVolumeBulkImportView,
-    LinuxVolumeBulkEditView,
-    LinuxVolumeBulkDeleteView,
-    LinuxVolumeView,
-    LinuxVolumeDeleteView, LVMAddSimpleView, AddSimpleLinuxVolumeView,
+    MountedVolumeListView,
+    MountedVolumeEditView,
+    MountedVolumeBulkImportView,
+    MountedVolumeBulkEditView,
+    MountedVolumeBulkDeleteView,
+    MountedVolumeView,
+    MountedVolumeDeleteView, LVMAddSimpleView, AddSimpleLinuxVolumeView,
 )
 
 app_name = "netbox_storage"
@@ -97,21 +97,21 @@ urlpatterns = [
         kwargs={"model": Partition},
     ),
     #
-    # LinuxVolume urls
+    # MountedVolume urls
     #
-    path("linuxvolume/", LinuxVolumeListView.as_view(), name="linuxvolume_list"),
-    path("linuxvolume/add/", LinuxVolumeEditView.as_view(), name="linuxvolume_add"),
-    path("linuxvolume/import/", LinuxVolumeBulkImportView.as_view(), name="linuxvolume_import"),
-    path("linuxvolume/edit/", LinuxVolumeBulkEditView.as_view(), name="linuxvolume_bulk_edit"),
-    path("linuxvolume/delete/", LinuxVolumeBulkDeleteView.as_view(), name="linuxvolume_bulk_delete"),
-    path("linuxvolume/<int:pk>/", LinuxVolumeView.as_view(), name="linuxvolume"),
-    path("linuxvolume/<int:pk>/edit/", LinuxVolumeEditView.as_view(), name="linuxvolume_edit"),
-    path("linuxvolume/<int:pk>/delete/", LinuxVolumeDeleteView.as_view(), name="linuxvolume_delete"),
+    path("mountedvolume/", MountedVolumeListView.as_view(), name="mountedvolume_list"),
+    path("mountedvolume/add/", MountedVolumeEditView.as_view(), name="mountedvolume_add"),
+    path("mountedvolume/import/", MountedVolumeBulkImportView.as_view(), name="mountedvolume_import"),
+    path("mountedvolume/edit/", MountedVolumeBulkEditView.as_view(), name="mountedvolume_bulk_edit"),
+    path("mountedvolume/delete/", MountedVolumeBulkDeleteView.as_view(), name="mountedvolume_bulk_delete"),
+    path("mountedvolume/<int:pk>/", MountedVolumeView.as_view(), name="mountedvolume"),
+    path("mountedvolume/<int:pk>/edit/", MountedVolumeEditView.as_view(), name="mountedvolume_edit"),
+    path("mountedvolume/<int:pk>/delete/", MountedVolumeDeleteView.as_view(), name="mountedvolume_delete"),
     path(
-        "linuxvolume/<int:pk>/changelog/",
+        "mountedvolume/<int:pk>/changelog/",
         ObjectChangeLogView.as_view(),
-        name="linuxvolume_changelog",
-        kwargs={"model": LinuxVolume},
+        name="mountedvolume_changelog",
+        kwargs={"model": MountedVolume},
     ),
     #
     # Simple Configuration
